from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, String, File, Int, Float

Atropos_Trim_V0_1_0 = CommandToolBuilder(tool="atropos_trim", base_command=["atropos", "trim"], inputs=[ToolInput(tag="in_debug", input_type=Boolean(optional=True), prefix="--debug", doc=InputDocumentation(doc="Print debugging information. (no)")), ToolInput(tag="in_progress", input_type=String(optional=True), prefix="--progress", doc=InputDocumentation(doc="Show progress. bar = show progress bar; msg = show a\nstatus message. (no)")), ToolInput(tag="in_quiet", input_type=Boolean(optional=True), prefix="--quiet", doc=InputDocumentation(doc="Print only error messages. (no)")), ToolInput(tag="in_log_level", input_type=String(optional=True), prefix="--log-level", doc=InputDocumentation(doc="Logging level. (ERROR when --quiet else INFO)")), ToolInput(tag="in_log_file", input_type=File(optional=True), prefix="--log-file", doc=InputDocumentation(doc="File to write logging info. (stdout)")), ToolInput(tag="in_input_one", input_type=File(optional=True), prefix="--input1", doc=InputDocumentation(doc="The first input file.")), ToolInput(tag="in_input_two", input_type=File(optional=True), prefix="--input2", doc=InputDocumentation(doc="The second input file.")), ToolInput(tag="in_interleaved_input", input_type=File(optional=True), prefix="--interleaved-input", doc=InputDocumentation(doc="Interleaved input file.")), ToolInput(tag="in_single_input", input_type=File(optional=True), prefix="--single-input", doc=InputDocumentation(doc="A single-end read file.")), ToolInput(tag="in_single_input_read", input_type=String(optional=True), prefix="--single-input-read", doc=InputDocumentation(doc="When treating an interleaved FASTQ or paired-end\nSAM/BAM file as single-end, this option specifies\nwhich of the two reads to process. (both reads used)")), ToolInput(tag="in_single_quals", input_type=File(optional=True), prefix="--single-quals", doc=InputDocumentation(doc="A single-end qual file.")), ToolInput(tag="in_sra_accession", input_type=String(optional=True), prefix="--sra-accession", doc=InputDocumentation(doc="Accession to stream from SRA (requires optional NGS\ndependency to be installed).")), ToolInput(tag="in_format", input_type=String(optional=True), prefix="--format", doc=InputDocumentation(doc="Input file format. Ignored when reading csfasta/qual\nfiles. (auto-detect from file name extension)")), ToolInput(tag="in_quality_base", input_type=Int(optional=True), prefix="--quality-base", doc=InputDocumentation(doc="Assume that quality values in FASTQ are encoded as\nascii(quality + QUALITY_BASE). This needs to be set to\n64 for some old Illumina FASTQ files. (33)")), ToolInput(tag="in_color_space", input_type=Boolean(optional=True), prefix="--colorspace", doc=InputDocumentation(doc="Enable colorspace mode: Also trim the color that is\nadjacent to the found adapter. (no)")), ToolInput(tag="in_max_reads", input_type=Int(optional=True), prefix="--max-reads", doc=InputDocumentation(doc="Maximum number of reads/pairs to process (no max)")), ToolInput(tag="in_subsample", input_type=String(optional=True), prefix="--subsample", doc=InputDocumentation(doc="Subsample a fraction of reads. (no)")), ToolInput(tag="in_subsample_seed", input_type=Int(optional=True), prefix="--subsample-seed", doc=InputDocumentation(doc="The seed to use for the pseudorandom number generator.\nUsing the same seed will result in the same\nsubsampling of reads.")), ToolInput(tag="in_batch_size", input_type=Int(optional=True), prefix="--batch-size", doc=InputDocumentation(doc="Number of records to process in each batch. (1000)")), ToolInput(tag="in_sample_id", input_type=String(optional=True), prefix="--sample-id", doc=InputDocumentation(doc="Optional sample ID. Added to the summary output.")), ToolInput(tag="in_alphabet", input_type=String(optional=True), prefix="--alphabet", doc=InputDocumentation(doc="Specify a sequence alphabet to use for validating\ninputs. Currently, only 'dna' is supported. (no\nvalidation)")), ToolInput(tag="in_adapter", input_type=Int(optional=True), prefix="--adapter", doc=InputDocumentation(doc="Sequence of an adapter ligated to the 3' end (paired\ndata: of the first read). The adapter and subsequent\nbases are trimmed. If a '$' character is appended\n('anchoring'), the adapter is only found if it is a\nsuffix of the read. (none)")), ToolInput(tag="in_front", input_type=Int(optional=True), prefix="--front", doc=InputDocumentation(doc="Sequence of an adapter ligated to the 5' end (paired\ndata: of the first read). The adapter and any\npreceding bases are trimmed. Partial matches at the 5'\nend are allowed. If a '^' character is prepended\n('anchoring'), the adapter is only found if it is a\nprefix of the read. (none)")), ToolInput(tag="in_anywhere", input_type=Int(optional=True), prefix="--anywhere", doc=InputDocumentation(doc="Sequence of an adapter that may be ligated to the 5'\nor 3' end (paired data: of the first read). Both types\nof matches as described under -a und -g are allowed.\nIf the first base of the read is part of the match,\nthe behavior is as with -g, otherwise as with -a. This\noption is mostly for rescuing failed library\npreparations - do not use if you know which end your\nadapter was ligated to! (none)")), ToolInput(tag="in_known_adapters_file", input_type=File(optional=True), prefix="--known-adapters-file", doc=InputDocumentation(doc="Path or URL of a FASTA file containing adapter\nsequences.")), ToolInput(tag="in_no_default_adapters", input_type=Boolean(optional=True), prefix="--no-default-adapters", doc=InputDocumentation(doc="Don't fetch the default adapter list (which is\ncurrently stored in GitHub).")), ToolInput(tag="in_adapter_cache_file", input_type=File(optional=True), prefix="--adapter-cache-file", doc=InputDocumentation(doc="File where adapter sequences will be cached, unless\n--no-cache-adapters is set.")), ToolInput(tag="in_no_cache_adapters", input_type=Boolean(optional=True), prefix="--no-cache-adapters", doc=InputDocumentation(doc="Don't cache adapters list as '.adapters' in the\nworking directory.")), ToolInput(tag="in_no_trim", input_type=Boolean(optional=True), prefix="--no-trim", doc=InputDocumentation(doc="Match and redirect reads to output/untrimmed-output as\nusual, but do not remove adapters. (no)")), ToolInput(tag="in_mask_adapter", input_type=Boolean(optional=True), prefix="--mask-adapter", doc=InputDocumentation(doc="Mask adapters with 'N' characters instead of trimming\nthem. (no)")), ToolInput(tag="in_gc_content", input_type=String(optional=True), prefix="--gc-content", doc=InputDocumentation(doc="Expected GC content of sequences.")), ToolInput(tag="in_aligner", input_type=String(optional=True), prefix="--aligner", doc=InputDocumentation(doc="Which alignment algorithm to use for identifying\nadapters. Currently, you can choose between the semi-\nglobal alignment strategy used in Cutdapt ('adapter')\nor the more accurate insert-based alignment algorithm\n('insert'). Note that insert-based alignment can only\nbe used with paired-end reads containing 3' adapters.\nNew algorithms are being implemented and the default\nis likely to change. (adapter)")), ToolInput(tag="in_error_rate", input_type=Int(optional=True), prefix="--error-rate", doc=InputDocumentation(doc="Maximum allowed error rate for adapter match (no. of\nerrors divided by the length of the matching region).\n(0.1)")), ToolInput(tag="in_in_del_cost", input_type=Int(optional=True), prefix="--indel-cost", doc=InputDocumentation(doc="Integer cost of insertions and deletions during\nadapter match. Substitutions always have a cost of 1.\n(1)")), ToolInput(tag="in_no_indels", input_type=Boolean(optional=True), prefix="--no-indels", doc=InputDocumentation(doc="Allow only mismatches in alignments. (allow both\nmismatches and indels)")), ToolInput(tag="in_times", input_type=Int(optional=True), prefix="--times", doc=InputDocumentation(doc="Remove up to COUNT adapters from each read. (1)")), ToolInput(tag="in_match_read_wildcards", input_type=Boolean(optional=True), prefix="--match-read-wildcards", doc=InputDocumentation(doc="Interpret IUPAC wildcards in reads. (no)")), ToolInput(tag="in_no_match_adapter_wildcards", input_type=Boolean(optional=True), prefix="--no-match-adapter-wildcards", doc=InputDocumentation(doc="Do not interpret IUPAC wildcards in adapters. (no)")), ToolInput(tag="in_overlap", input_type=Int(optional=True), prefix="--overlap", doc=InputDocumentation(doc="If the overlap between the read and the adapter is\nshorter than MINLENGTH, the read is not modified.\nReduces the no. of bases trimmed due to random adapter\nmatches. (3)")), ToolInput(tag="in_adapter_max_rmp", input_type=Int(optional=True), prefix="--adapter-max-rmp", doc=InputDocumentation(doc="If no minimum overlap (-O) is specified, then adapters\nare only matched when the probabilty of observing k\nout of n matching bases is <= PROB. (1E-6)")), ToolInput(tag="in_insert_max_rmp", input_type=Int(optional=True), prefix="--insert-max-rmp", doc=InputDocumentation(doc="Overlapping inserts only match when the probablity of\nobserving k of n matching bases is <= PROB. (1E-6)")), ToolInput(tag="in_insert_match_error_rate", input_type=Int(optional=True), prefix="--insert-match-error-rate", doc=InputDocumentation(doc="Maximum allowed error rate for insert match (no. of\nerrors divided by the length of the matching region).\n(0.2)")), ToolInput(tag="in_insert_match_adapter_error_rate", input_type=Int(optional=True), prefix="--insert-match-adapter-error-rate", doc=InputDocumentation(doc="Maximum allowed error rate for matching adapters after\nsuccessful insert match (no. of errors divided by the\nlength of the matching region). (0.2)")), ToolInput(tag="in_merge_overlapping", input_type=Boolean(optional=True), prefix="--merge-overlapping", doc=InputDocumentation(doc="Merge read pairs that overlap into a single sequence.\nThis is experimental. (no)")), ToolInput(tag="in_merge_min_overlap", input_type=Int(optional=True), prefix="--merge-min-overlap", doc=InputDocumentation(doc="The minimum overlap between reads required for\nmerging. If this number is (0,1.0], it specifies the\nminimum length as the fraction of the length of the\n*shorter* read in the pair; otherwise it specifies the\nminimum number of overlapping base pairs (with an\nabsolute minimum of 2 bp). (0.9)")), ToolInput(tag="in_merge_error_rate", input_type=Float(optional=True), prefix="--merge-error-rate", doc=InputDocumentation(doc="The maximum error rate for merging. (0.2)")), ToolInput(tag="in_correct_mismatches", input_type=String(optional=True), prefix="--correct-mismatches", doc=InputDocumentation(doc="How to handle mismatches while aligning/merging.\n'Liberal' and 'conservative' error correction both\ninvolve setting the base to the one with the best\nquality. They differ only when the qualities are equal\n-- liberal means set it to the base from the read with\nthe overall best median base quality, while\nconservative means to leave it unchanged. 'N' means to\nset the base to N. If exactly one base is ambiguous,\nthe non-ambiguous base is always used. (no error\ncorrection)")), ToolInput(tag="in_op_order", input_type=String(optional=True), prefix="--op-order", doc=InputDocumentation(doc="The order in which trimming operations are be applied.\nThis is a string of 1-5 of the following characters: A\n= adapter trimming; C = cutting (unconditional); G =\nNextSeq trimming; Q = quality trimming; W = overwrite\npoor quality reads. The default is 'WCGQA' to maintain\ncompatibility with Cutadapt; however, this is likely\nto change to 'GAWCQ' in the near future.")), ToolInput(tag="in_cut", input_type=Int(optional=True), prefix="--cut", doc=InputDocumentation(doc="Remove bases from each read (first read only if\npaired). If LENGTH is positive, remove bases from the\nbeginning. If LENGTH is negative, remove bases from\nthe end. Can be used twice if LENGTHs have different\nsigns. (no)")), ToolInput(tag="in_cutofftrim_lowquality_bases", input_type=Boolean(optional=True), prefix="-q", doc=InputDocumentation(doc="[5'CUTOFF,]3'CUTOFF, --quality-cutoff [5'CUTOFF,]3'CUTOFF\nTrim low-quality bases from 5' and/or 3' ends of each\nread before adapter removal. Applied to both reads if\ndata is paired. If one value is given, only the 3' end\nis trimmed. If two comma-separated cutoffs are given,\nthe 5' end is trimmed with the first cutoff, the 3'\nend with the second. (no)")), ToolInput(tag="in_cut_min", input_type=Int(optional=True), prefix="--cut-min", doc=InputDocumentation(doc="Similar to -u, except that cutting is done AFTER\nadapter trimming, and only if a minimum of LENGTH\nbases was not already removed. (no)")), ToolInput(tag="in_next_seq_trim", input_type=Int(optional=True), prefix="--nextseq-trim", doc=InputDocumentation(doc="'CUTOFF\nNextSeq-specific quality trimming (each read). Trims\nalso dark cycles appearing as high-quality G bases\n(EXPERIMENTAL). (no)")), ToolInput(tag="in_trim_n", input_type=Boolean(optional=True), prefix="--trim-n", doc=InputDocumentation(doc="Trim N's on ends of reads. (no)")), ToolInput(tag="in_prefix", input_type=String(optional=True), prefix="--prefix", doc=InputDocumentation(doc="Add this prefix to read names. Use {name} to insert\nthe name of the matching adapter. (no)")), ToolInput(tag="in_suffix", input_type=String(optional=True), prefix="--suffix", doc=InputDocumentation(doc="Add this suffix to read names; can also include\n{name}. (no)")), ToolInput(tag="in_strip_suffix", input_type=String(optional=True), prefix="--strip-suffix", doc=InputDocumentation(doc="Remove this suffix from read names if present. Can be\ngiven multiple times. (no)")), ToolInput(tag="in_length_tag", input_type=Int(optional=True), prefix="--length-tag", doc=InputDocumentation(doc="Search for TAG followed by a decimal number in the\ndescription field of the read. Replace the decimal\nnumber with the correct length of the trimmed read.\nFor example, use --length-tag 'length=' to correct\nfields like 'length=123'. (no)")), ToolInput(tag="in_discard_trimmed", input_type=Boolean(optional=True), prefix="--discard-trimmed", doc=InputDocumentation(doc="Discard reads that contain an adapter. Also use -O to\navoid discarding too many randomly matching reads!\n(no)")), ToolInput(tag="in_discard_untrimmed", input_type=Boolean(optional=True), prefix="--discard-untrimmed", doc=InputDocumentation(doc="Discard reads that do not contain the adapter. (no)")), ToolInput(tag="in_minimum_length", input_type=Int(optional=True), prefix="--minimum-length", doc=InputDocumentation(doc="Discard trimmed reads that are shorter than LENGTH.\nReads that are too short even before adapter removal\nare also discarded. In colorspace, an initial primer\nis not counted. (0)")), ToolInput(tag="in_maximum_length", input_type=Int(optional=True), prefix="--maximum-length", doc=InputDocumentation(doc="Discard trimmed reads that are longer than LENGTH.\nReads that are too long even before adapter removal\nare also discarded. In colorspace, an initial primer\nis not counted. (no limit)")), ToolInput(tag="in_max_n", input_type=Int(optional=True), prefix="--max-n", doc=InputDocumentation(doc="Discard reads with too many N bases. If COUNT is an\ninteger, it is treated as the absolute number of N\nbases. If it is between 0 and 1, it is treated as the\nproportion of N's allowed in a read. (no)")), ToolInput(tag="in_output", input_type=File(optional=True), prefix="--output", doc=InputDocumentation(doc="Write trimmed reads to FILE. FASTQ or FASTA format is\nchosen depending on input. The summary report is sent\nto standard output. Use '{name}' in FILE to\ndemultiplex reads into multiple files. (write to\nstandard output)")), ToolInput(tag="in_info_file", input_type=File(optional=True), prefix="--info-file", doc=InputDocumentation(doc="Write information about each read and its adapter\nmatches into FILE. See the documentation for the file\nformat. (no)")), ToolInput(tag="in_rest_file", input_type=File(optional=True), prefix="--rest-file", doc=InputDocumentation(doc="When the adapter matches in the middle of a read,\nwrite the rest (after the adapter) into FILE. (no)")), ToolInput(tag="in_wildcard_file", input_type=File(optional=True), prefix="--wildcard-file", doc=InputDocumentation(doc="When the adapter has N bases (wildcards), write\nadapter bases matching wildcard positions to FILE.\nWhen there are indels in the alignment, this will\noften not be accurate. (no)")), ToolInput(tag="in_too_short_output", input_type=File(optional=True), prefix="--too-short-output", doc=InputDocumentation(doc="Write reads that are too short (according to length\nspecified by -m) to FILE. (no - too short reads are\ndiscarded)")), ToolInput(tag="in_too_long_output", input_type=File(optional=True), prefix="--too-long-output", doc=InputDocumentation(doc="Write reads that are too long (according to length\nspecified by -M) to FILE. (no - too long reads are\ndiscarded)")), ToolInput(tag="in_untrimmed_output", input_type=File(optional=True), prefix="--untrimmed-output", doc=InputDocumentation(doc="Write reads that do not contain the adapter to FILE.\n(no - untrimmed reads are written to default output)")), ToolInput(tag="in_merged_output", input_type=File(optional=True), prefix="--merged-output", doc=InputDocumentation(doc="Write reads that have been merged to this file.\n(merged reads are discarded)")), ToolInput(tag="in_report_file", input_type=File(optional=True), prefix="--report-file", doc=InputDocumentation(doc="Write report to file rather than stdout/stderr. (no)")), ToolInput(tag="in_report_formats", input_type=File(optional=True), prefix="--report-formats", doc=InputDocumentation(doc="[FORMAT [FORMAT ...]]\nReport type(s) to generate. If multiple, '--report-\nfile' is treated as a prefix and the appropriate\nextensions are appended. If unspecified, the format is\nguessed from the file extension. Supported formats\nare: txt (legacy text format), json, yaml, pickle. See\nthe documentation for a full description of the\nstructured output (json/yaml/pickle formats).")), ToolInput(tag="in_stats", input_type=Boolean(optional=True), prefix="--stats", doc=InputDocumentation(doc="[STATS [STATS ...]]\nWhich read-level statistics to compute. Can be 'none'\n(default), 'pre': only compute pre-trimming stats;\n'post': only compute post-trimming stats; or 'both'.\nThe keyword can be followed by ':' and then additional\nconfiguration parameters. E.g. 'pre:tiles' means to\nalso collect tile-level statistics (Illumina data\nonly), and 'pre:tiles=<regexp>' means to use the\nspecified regular expression to extract key portions\nof read names to collect the tile statistics.")), ToolInput(tag="in_double_encode", input_type=Boolean(optional=True), prefix="--double-encode", doc=InputDocumentation(doc="Double-encode colors (map 0,1,2,3,4 to A,C,G,T,N).\n(no)")), ToolInput(tag="in_trim_primer", input_type=Boolean(optional=True), prefix="--trim-primer", doc=InputDocumentation(doc="Trim primer base and the first color (which is the\ntransition to the first nucleotide). (no)")), ToolInput(tag="in_strip_f_three", input_type=Boolean(optional=True), prefix="--strip-f3", doc=InputDocumentation(doc="Strip the _F3 suffix of read names. (no)")), ToolInput(tag="in_maq", input_type=Boolean(optional=True), prefix="--maq", doc=InputDocumentation(doc="MAQ- and BWA-compatible colorspace output. This\nenables -c, -d, -t, --strip-f3 and -y '/1'. (no)")), ToolInput(tag="in_no_zero_cap", input_type=Boolean(optional=True), prefix="--no-zero-cap", doc=InputDocumentation(doc="Do not change negative quality values to zero in\ncolorspace data. By default, they are since many tools\nhave problems with negative qualities. (no)")), ToolInput(tag="in_zero_cap", input_type=Boolean(optional=True), prefix="--zero-cap", doc=InputDocumentation(doc="Change negative quality values to zero. This is\nenabled by default when -c/--colorspace is also\nenabled. Use the above option to disable it. (no)")), ToolInput(tag="in_adapter_two", input_type=Int(optional=True), prefix="--adapter2", doc=InputDocumentation(doc="3' adapter to be removed from second read in a pair.\n(no)")), ToolInput(tag="in_front_two", input_type=Int(optional=True), prefix="--front2", doc=InputDocumentation(doc="5' adapter to be removed from second read in a pair.\n(no)")), ToolInput(tag="in_anywhere_two", input_type=Int(optional=True), prefix="--anywhere2", doc=InputDocumentation(doc="5'/3 adapter to be removed from second read in a pair.\n(no)")), ToolInput(tag="in_cut_two", input_type=Int(optional=True), prefix="--cut2", doc=InputDocumentation(doc="Remove LENGTH bases from second read in a pair (see\n--cut). (no)")), ToolInput(tag="in_cut_min_two", input_type=Int(optional=True), prefix="--cut-min2", doc=InputDocumentation(doc="Similar to -U, except that cutting is done AFTER\nadapter trimming, and only if a minimum of LENGTH\nbases was not already removed (see --cut-min). (no)")), ToolInput(tag="in_highqwindow__overwritelowquality", input_type=String(optional=True), prefix="-w", doc=InputDocumentation(doc=",HIGHQ,WINDOW, --overwrite-low-quality LOWQ,HIGHQ,WINDOW\nWhen one read has mean quality < LOWQ and the other\nread has mean quality >= HIGHQ over the first WINDOW\nbases, overwrite the worse read with the better read.")), ToolInput(tag="in_paired_output", input_type=File(optional=True), prefix="--paired-output", doc=InputDocumentation(doc="Write second read in a pair to FILE. (no)")), ToolInput(tag="in_interleaved_output", input_type=File(optional=True), prefix="--interleaved-output", doc=InputDocumentation(doc="Write output to interleaved file.")), ToolInput(tag="in_pair_filter", input_type=Boolean(optional=True), prefix="--pair-filter", doc=InputDocumentation(doc="(any|both)\nWhich of the reads in a paired-end read have to match\nthe filtering criterion in order for it to be\nfiltered. (any)")), ToolInput(tag="in_untrimmed_paired_output", input_type=File(optional=True), prefix="--untrimmed-paired-output", doc=InputDocumentation(doc="Write second read in a pair to this FILE when no\nadapter was found in the first read. Use this option\ntogether with --untrimmed-output when trimming paired-\nend reads. (no - output to same file as trimmed reads)")), ToolInput(tag="in_too_short_paired_output", input_type=File(optional=True), prefix="--too-short-paired-output", doc=InputDocumentation(doc="Write second read in a pair to this file if pair is\ntoo short. Use together with --too-short-output. (no -\ntoo short reads are discarded)")), ToolInput(tag="in_too_long_paired_output", input_type=File(optional=True), prefix="--too-long-paired-output", doc=InputDocumentation(doc="Write second read in a pair to this file if pair is\ntoo long. Use together with --too-long-output. (no -\ntoo long reads are discarded)")), ToolInput(tag="in_bisulfite", input_type=Int(optional=True), prefix="--bisulfite", doc=InputDocumentation(doc="Set default option values for bisulfite-treated data.\nThe argument specifies the type of bisulfite library\n(rrbs, non-directional, non-directional-rrbs, truseq,\nepignome, or swift) or custom parameters for trimming:\n'<read1>[;<read2>]' where trimming parameters for each\nread are: '<5' cut>,<3' cut>,<include trimmed>,<only\ntrimmed>' where 'include trimmed' is 1 or 0 for\nwhether or not the bases already trimmed during/prior\nto adapter trimming should be counted towards the\ntotal bases to be cut and 'only trimmed' is 1 or 0 for\nwhether or not only trimmed reads should be further\ncut. (no)")), ToolInput(tag="in_mirna", input_type=Boolean(optional=True), prefix="--mirna", doc=InputDocumentation(doc="Set default option values for miRNA data. (no)")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="--threads", doc=InputDocumentation(doc="Number of threads to use for read trimming. Set to 0\nto use max available threads. (Do not use\nmultithreading)")), ToolInput(tag="in_no_writer_process", input_type=File(optional=True), prefix="--no-writer-process", doc=InputDocumentation(doc="Do not use a writer process; instead, each worker\nthread writes its own output to a file with a '.N'\nsuffix. (no)")), ToolInput(tag="in_preserve_order", input_type=Boolean(optional=True), prefix="--preserve-order", doc=InputDocumentation(doc="Preserve order of reads in input files (ignored if")), ToolInput(tag="in_process_timeout", input_type=Int(optional=True), prefix="--process-timeout", doc=InputDocumentation(doc="Number of seconds process should wait before\nescalating messages to ERROR level. (60)")), ToolInput(tag="in_read_queue_size", input_type=Int(optional=True), prefix="--read-queue-size", doc=InputDocumentation(doc="Size of queue for batches of reads to be processed.\n(THREADS * 100)")), ToolInput(tag="in_result_queue_size", input_type=Int(optional=True), prefix="--result-queue-size", doc=InputDocumentation(doc="Size of queue for batches of results to be written.\n(THREADS * 100)")), ToolInput(tag="in_compression", input_type=String(optional=True), prefix="--compression", doc=InputDocumentation(doc="Where data compression should be performed. Defaults\nto 'writer' if system-level compression can be used\nand (1 < threads < 8), otherwise defaults to 'worker'.\n"))], outputs=[ToolOutput(tag="out_untrimmed_output", output_type=File(optional=True), selector=InputSelector(input_to_select="in_untrimmed_output", type_hint=File()), doc=OutputDocumentation(doc="Write reads that do not contain the adapter to FILE.\n(no - untrimmed reads are written to default output)")), ToolOutput(tag="out_report_formats", output_type=File(optional=True), selector=InputSelector(input_to_select="in_report_formats", type_hint=File()), doc=OutputDocumentation(doc="[FORMAT [FORMAT ...]]\nReport type(s) to generate. If multiple, '--report-\nfile' is treated as a prefix and the appropriate\nextensions are appended. If unspecified, the format is\nguessed from the file extension. Supported formats\nare: txt (legacy text format), json, yaml, pickle. See\nthe documentation for a full description of the\nstructured output (json/yaml/pickle formats).")), ToolOutput(tag="out_interleaved_output", output_type=File(optional=True), selector=InputSelector(input_to_select="in_interleaved_output", type_hint=File()), doc=OutputDocumentation(doc="Write output to interleaved file.")), ToolOutput(tag="out_untrimmed_paired_output", output_type=File(optional=True), selector=InputSelector(input_to_select="in_untrimmed_paired_output", type_hint=File()), doc=OutputDocumentation(doc="Write second read in a pair to this FILE when no\nadapter was found in the first read. Use this option\ntogether with --untrimmed-output when trimming paired-\nend reads. (no - output to same file as trimmed reads)")), ToolOutput(tag="out_too_short_paired_output", output_type=File(optional=True), selector=InputSelector(input_to_select="in_too_short_paired_output", type_hint=File()), doc=OutputDocumentation(doc="Write second read in a pair to this file if pair is\ntoo short. Use together with --too-short-output. (no -\ntoo short reads are discarded)")), ToolOutput(tag="out_too_long_paired_output", output_type=File(optional=True), selector=InputSelector(input_to_select="in_too_long_paired_output", type_hint=File()), doc=OutputDocumentation(doc="Write second read in a pair to this file if pair is\ntoo long. Use together with --too-long-output. (no -\ntoo long reads are discarded)")), ToolOutput(tag="out_no_writer_process", output_type=File(optional=True), selector=InputSelector(input_to_select="in_no_writer_process", type_hint=File()), doc=OutputDocumentation(doc="Do not use a writer process; instead, each worker\nthread writes its own output to a file with a '.N'\nsuffix. (no)"))], container="quay.io/biocontainers/atropos:1.1.29--py37hf01694f_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Atropos_Trim_V0_1_0().translate("wdl")

